==> 1.0.1.tar.gz: calebasse/calebasse/utils.py <==
from django.contrib.auth.models import Group

from datetime import timedelta, datetime

__EPOCH = datetime(day=5,month=1,year=1970)

def __date_to_datetime(date):
    return datetime(date.year, date.month, date.day)

def weeks_since_epoch(date):
    days_since_epoch = (__date_to_datetime(date) - __EPOCH).days
    return days_since_epoch // 7

def weekday_ranks(date):
    '''Returns n so that if date occurs on a certain weekday, this is the
    n-th weekday of the month counting from 0. Also return 4 if this the
    last suck weekday of the month. '''
    n = 0
    month = date.month
    i = date - timedelta(days=7)
    while i.month == month:
        n += 1
        i = i - timedelta(days=7)
    if (date+timedelta(days=7)).month != month and n != 4:
        return n, 4
    else:
        return n,

def is_super_user(user):
    if not user or not user.is_authenticated():
        return False
    if user.is_superuser:
        return True
    super_group = None
    try:
        super_group = Group.objects.get(name='Super utilisateurs')
    except:
        return False
    if super_group in user.groups.all():
        return True
    return False

def is_validator(user):
    if is_super_user(user):
        return True
    if not user or not user.is_authenticated():
        return False
    validator_group = None
    try:
        validator_group = Group.objects.get(name='Administratifs')
    except:
        return False
    if validator_group in user.groups.all():
        return True
    return False

==> 1.1.1.tar.gz: calebasse/calebasse/utils.py <==
from django.contrib.auth.models import Group

from datetime import timedelta, datetime

__EPOCH = datetime(day=5,month=1,year=1970)

def __date_to_datetime(date):
    return datetime(date.year, date.month, date.day)

def weeks_since_epoch(date):
    days_since_epoch = (__date_to_datetime(date) - __EPOCH).days
    return days_since_epoch // 7

def weekday_ranks(date):
    '''Returns n so that if date occurs on a certain weekday, this is the
       n-th weekday of the month counting from the first. Also return -n-1 if
       this is the n-th weekday of the month counting from the last.
    '''
    n = 0
    month = date.month
    i = date - timedelta(days=7)
    while i.month == month:
        n += 1
        i = i - timedelta(days=7)
    m = -1
    i = date + timedelta(days=7)
    while i.month == month:
        m -= 1
        i = i + timedelta(days=7)
    return n, m

def is_super_user(user):
    if not user or not user.is_authenticated():
        return False
    if user.is_superuser:
        return True
    super_group = None
    try:
        super_group = Group.objects.get(name='Super utilisateurs')
    except:
        return False
    if super_group in user.groups.all():
        return True
    return False

def is_validator(user):
    if is_super_user(user):
        return True
    if not user or not user.is_authenticated():
        return False
    validator_group = None
    try:
        validator_group = Group.objects.get(name='Administratifs')
    except:
        return False
    if validator_group in user.groups.all():
        return True
    return False

def get_nir_control_key(nir):
    try:
        # Corse dpt 2A et 2B
        minus = 0
        if nir[6] in ('A', 'a'):
            nir = [c for c in nir]
            nir[6] = '0'
            nir = ''.join(nir)
            minus = 1000000
        elif nir[6] in ('B', 'b'):
            nir = [c for c in nir]
            nir[6] = '0'
            nir = ''.join(nir)
            minus = 2000000
        nir = int(nir) - minus
        return (97 - (nir % 97))
    except:
        return None
